/*
 * tmos - romdisk.c
 *
 * 	ROM disk support
 * 
 * Copyright (C) 2010  Krzysztof Mazur <krzysiek@podlesie.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Fundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include <tmos/kernel.h>
#include <tmos/port.h>
#include <tmos/errno.h>
#include <asm/aduc841.h>
#include <tmos/string.h>

static __code char rom_data[] = {
#include "romdisk-data.h"
};

#define ROM_SIZE ARRAY_SIZE(rom_data)

msg_ssize_t dev_romdisk_xmit(port_t port, char __kernel *buf,
		msg_size_t len, msg_size_t max_resp_len, msg_flags_t flags,
		off_t off)
	__reentrant
{
	msg_ssize_t ret = 0;
		
	if (off >= ROM_SIZE)
		return 0;

	if (len)
		return -EINVAL;

	if (max_resp_len) {
		if (max_resp_len > ROM_SIZE - off)
			max_resp_len = ROM_SIZE - off;
		memcpy(buf, rom_data + off, max_resp_len);
		ret = max_resp_len;
	}
	return ret;
}
