/*
 * wysmod - ser_lcdemu.c
 *
 * 	WYDMOD serial LCD emulation console support
 *
 * Copyright (C) 2007  Krzysztof Mazur <krzysiek@podlesie.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <tmos/kernel.h>
#include <tmos/ser_lcdemu.h>
#include <tmos/serial.h>

#define FB_SIZE		(CONSOLE_ROWS * CONSOLE_COLS)

static char fb[FB_SIZE];

void c_clear_row(char row)
{
	char i;

	for (i = c_mkpos(row, 0); i < c_mkpos(row, CONSOLE_COLS); i++)
		fb[i] = ' ';
}

void c_clear(void)
{
	char i;

	for (i = 0; i < FB_SIZE; i++)
		fb[i] = ' ';
}

/* initialize console */
void console_init(void)
{
	ser_txs("Serial LCD console emulation init.\n");
	c_clear();
}

void c_putchar_p(char pos, char c)
{
	fb[pos] = c;
}

void c_flush(void)
{
	char i;

	ser_txs("---\n");
	for (i = 0; i < CONSOLE_ROWS; i++) {
		ser_txd(fb + i * CONSOLE_COLS, CONSOLE_COLS);
		ser_txc('|');
		ser_txc('\n');
	}
}

device_initcall(console_init)
